@@ -70,12 +70,16 @@ impl TailwindError {
     pub fn set_range(&mut self, start: usize, end: usize) {
         self.range = Some(Range { start, end });
     }
+    /// Constructor of [`NoteErrorKind::Incomplete`]
+    #[inline]
+    pub fn incomplete() -> Self {
+        Self { kind: Box::new(TailwindErrorKind::Incomplete), level: DiagnosticLevel::None, file: None, range: None }
+    }
     /// Constructor of [`NoteErrorKind::Unreachable`]
     #[inline]
     pub fn unreachable() -> Self {
         Self { kind: Box::new(TailwindErrorKind::Unreachable), level: DiagnosticLevel::None, file: None, range: None }
     }
-
     /// Constructor of [`NoteErrorKind::UndefinedVariable`]
     #[inline]
     pub fn undefined_variable(name: impl Into<String>) -> TailwindError {
